autodiffy: Automatic Differentiation Package

+ Andrew Chia
+ Will Fried
+ Ankith Harathi 
+ Wei-Hung Hsu

For documentation and development, visit [our github](https://github.com/CS207-Feiyu-Group8/cs207-FinalProject)